# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/predictionstore/v1/predictionstore.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/predictionstore/v1/predictionstore.proto',
  package='github.com.metaprov.modelaapi.services.predictionstore.v1',
  syntax='proto3',
  serialized_options=b'Z9github.com/metaprov/modelaapi/services/predictionstore/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nOgithub.com/metaprov/modelaapi/services/predictionstore/v1/predictionstore.proto\x12\x39github.com.metaprov.modelaapi.services.predictionstore.v1\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a\"k8s.io/api/core/v1/generated.proto\"\xfa\x01\n\x18PredictionsIngestRequest\x12N\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x0b\n\x03key\x18\x02 \x01(\t\x12U\n\nconnection\x18\x03 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12*\n\x06secret\x18\x04 \x01(\x0b\x32\x1a.k8s.io.api.core.v1.Secret\"\x1a\n\x18PredictionIngestResponse2\xcf\x01\n\x16PredictionStoreService\x12\xb4\x01\n\x06Ingest\x12S.github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionsIngestRequest\x1aS.github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionIngestResponse\"\x00\x42;Z9github.com/metaprov/modelaapi/services/predictionstore/v1b\x06proto3'
  ,
  dependencies=[github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2.DESCRIPTOR,])




_PREDICTIONSINGESTREQUEST = _descriptor.Descriptor(
  name='PredictionsIngestRequest',
  full_name='github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionsIngestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionsIngestRequest.dataset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionsIngestRequest.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionsIngestRequest.connection', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionsIngestRequest.secret', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=570,
)


_PREDICTIONINGESTRESPONSE = _descriptor.Descriptor(
  name='PredictionIngestResponse',
  full_name='github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionIngestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=572,
  serialized_end=598,
)

_PREDICTIONSINGESTREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_PREDICTIONSINGESTREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_PREDICTIONSINGESTREQUEST.fields_by_name['secret'].message_type = k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2._SECRET
DESCRIPTOR.message_types_by_name['PredictionsIngestRequest'] = _PREDICTIONSINGESTREQUEST
DESCRIPTOR.message_types_by_name['PredictionIngestResponse'] = _PREDICTIONINGESTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PredictionsIngestRequest = _reflection.GeneratedProtocolMessageType('PredictionsIngestRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTIONSINGESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictionstore.v1.predictionstore_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionsIngestRequest)
  })
_sym_db.RegisterMessage(PredictionsIngestRequest)

PredictionIngestResponse = _reflection.GeneratedProtocolMessageType('PredictionIngestResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTIONINGESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictionstore.v1.predictionstore_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionIngestResponse)
  })
_sym_db.RegisterMessage(PredictionIngestResponse)


DESCRIPTOR._options = None

_PREDICTIONSTORESERVICE = _descriptor.ServiceDescriptor(
  name='PredictionStoreService',
  full_name='github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionStoreService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=601,
  serialized_end=808,
  methods=[
  _descriptor.MethodDescriptor(
    name='Ingest',
    full_name='github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionStoreService.Ingest',
    index=0,
    containing_service=None,
    input_type=_PREDICTIONSINGESTREQUEST,
    output_type=_PREDICTIONINGESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREDICTIONSTORESERVICE)

DESCRIPTOR.services_by_name['PredictionStoreService'] = _PREDICTIONSTORESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/alert/v1/alert.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/alert/v1/alert.proto',
  package='github.com.metaprov.modelaapi.services.alert.v1',
  syntax='proto3',
  serialized_options=b'Z/github.com/metaprov/modelaapi/services/alert/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;github.com/metaprov/modelaapi/services/alert/v1/alert.proto\x12/github.com.metaprov.modelaapi.services.alert.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xb5\x01\n\x11ListAlertsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12^\n\x06labels\x18\x02 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x12ListAlertsResponse\x12O\n\x05items\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.AlertList\"\x0f\n\rAlertResponse\"r\n\x12\x43reateAlertRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\x12\x10\n\x08password\x18\x02 \x01(\t\"\x15\n\x13\x43reateAlertResponse\"`\n\x12UpdateAlertRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"\x15\n\x13UpdateAlertResponse\"2\n\x0fGetAlertRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"l\n\x10GetAlertResponse\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"<\n\x19GetAlertNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"q\n\x1aGetAlertNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"5\n\x12\x44\x65leteAlertRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteAlertResponse\"\x15\n\x13\x41lertCreateResponse\"\x10\n\x0eLogoutResponse\"\x17\n\x15ResetPasswordResponse\"F\n\x11\x41lertLoginRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"#\n\x12\x41lertLoginResponse\x12\r\n\x05token\x18\x01 \x01(\t\"8\n\x15\x41lertGetByNameRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"#\n\x12\x41lertLogoutRequest\x12\r\n\x05token\x18\x01 \x01(\t\"h\n\x15\x43hangePasswordRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03old\x18\x03 \x01(\t\x12\x0b\n\x03new\x18\x04 \x01(\t\x12\x14\n\x0c\x63onfirmedNew\x18\x05 \x01(\t\"\x18\n\x16\x43hangePasswordResponse\"Z\n\x14ResetPasswordRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03new\x18\x03 \x01(\t\x12\x14\n\x0c\x63onfirmedNew\x18\x04 \x01(\t\"\x16\n\x14ResetPasswordReponse2\xd7\x07\n\x0c\x41lertService\x12\xa9\x01\n\nListAlerts\x12\x42.github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest\x1a\x43.github.com.metaprov.modelaapi.services.alert.v1.ListAlertsResponse\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/v1/alerts\x12\xb3\x01\n\x0b\x43reateAlert\x12\x43.github.com.metaprov.modelaapi.services.alert.v1.CreateAlertRequest\x1a\x44.github.com.metaprov.modelaapi.services.alert.v1.CreateAlertResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\n/v1/alerts:\x05\x61lert\x12\xb6\x01\n\x08GetAlert\x12@.github.com.metaprov.modelaapi.services.alert.v1.GetAlertRequest\x1a\x41.github.com.metaprov.modelaapi.services.alert.v1.GetAlertResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/{namespace}/alerts/{name}\x12\xe5\x01\n\x0bUpdateAlert\x12\x43.github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertRequest\x1a\x44.github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertResponse\"K\x82\xd3\xe4\x93\x02\x45\x1a</v1/{alert.metadata.namespace}/alerts//{alert.metadata.name}:\x05\x61lert\x12\xc3\x01\n\x0b\x44\x65leteAlert\x12\x43.github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertRequest\x1a\x44.github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertResponse\")\x82\xd3\xe4\x93\x02#*!/api/{namespace}/v1/alerts/{name}B1Z/github.com/metaprov/modelaapi/services/alert/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTALERTSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=458,
)

_LISTALERTSREQUEST = _descriptor.Descriptor(
  name='ListAlertsRequest',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTALERTSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=458,
)


_LISTALERTSRESPONSE = _descriptor.Descriptor(
  name='ListAlertsResponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.ListAlertsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.alert.v1.ListAlertsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=561,
)


_ALERTRESPONSE = _descriptor.Descriptor(
  name='AlertResponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=563,
  serialized_end=578,
)


_CREATEALERTREQUEST = _descriptor.Descriptor(
  name='CreateAlertRequest',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.CreateAlertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.alert.v1.CreateAlertRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='github.com.metaprov.modelaapi.services.alert.v1.CreateAlertRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=694,
)


_CREATEALERTRESPONSE = _descriptor.Descriptor(
  name='CreateAlertResponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.CreateAlertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=696,
  serialized_end=717,
)


_UPDATEALERTREQUEST = _descriptor.Descriptor(
  name='UpdateAlertRequest',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=719,
  serialized_end=815,
)


_UPDATEALERTRESPONSE = _descriptor.Descriptor(
  name='UpdateAlertResponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=817,
  serialized_end=838,
)


_GETALERTREQUEST = _descriptor.Descriptor(
  name='GetAlertRequest',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.GetAlertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.alert.v1.GetAlertRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.alert.v1.GetAlertRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=840,
  serialized_end=890,
)


_GETALERTRESPONSE = _descriptor.Descriptor(
  name='GetAlertResponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.GetAlertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.alert.v1.GetAlertResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.alert.v1.GetAlertResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=892,
  serialized_end=1000,
)


_GETALERTNAMESPACESREQUEST = _descriptor.Descriptor(
  name='GetAlertNamespacesRequest',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.GetAlertNamespacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.alert.v1.GetAlertNamespacesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.alert.v1.GetAlertNamespacesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1002,
  serialized_end=1062,
)


_GETALERTNAMESPACESRESPONSE = _descriptor.Descriptor(
  name='GetAlertNamespacesResponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.GetAlertNamespacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespaces', full_name='github.com.metaprov.modelaapi.services.alert.v1.GetAlertNamespacesResponse.namespaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1064,
  serialized_end=1177,
)


_DELETEALERTREQUEST = _descriptor.Descriptor(
  name='DeleteAlertRequest',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1179,
  serialized_end=1232,
)


_DELETEALERTRESPONSE = _descriptor.Descriptor(
  name='DeleteAlertResponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1234,
  serialized_end=1255,
)


_ALERTCREATERESPONSE = _descriptor.Descriptor(
  name='AlertCreateResponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1257,
  serialized_end=1278,
)


_LOGOUTRESPONSE = _descriptor.Descriptor(
  name='LogoutResponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.LogoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1280,
  serialized_end=1296,
)


_RESETPASSWORDRESPONSE = _descriptor.Descriptor(
  name='ResetPasswordResponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.ResetPasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1298,
  serialized_end=1321,
)


_ALERTLOGINREQUEST = _descriptor.Descriptor(
  name='AlertLoginRequest',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertLoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertLoginRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertLoginRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertLoginRequest.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=1393,
)


_ALERTLOGINRESPONSE = _descriptor.Descriptor(
  name='AlertLoginResponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertLoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertLoginResponse.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1395,
  serialized_end=1430,
)


_ALERTGETBYNAMEREQUEST = _descriptor.Descriptor(
  name='AlertGetByNameRequest',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertGetByNameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertGetByNameRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertGetByNameRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1432,
  serialized_end=1488,
)


_ALERTLOGOUTREQUEST = _descriptor.Descriptor(
  name='AlertLogoutRequest',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertLogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertLogoutRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1490,
  serialized_end=1525,
)


_CHANGEPASSWORDREQUEST = _descriptor.Descriptor(
  name='ChangePasswordRequest',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.ChangePasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.alert.v1.ChangePasswordRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.alert.v1.ChangePasswordRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old', full_name='github.com.metaprov.modelaapi.services.alert.v1.ChangePasswordRequest.old', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new', full_name='github.com.metaprov.modelaapi.services.alert.v1.ChangePasswordRequest.new', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confirmedNew', full_name='github.com.metaprov.modelaapi.services.alert.v1.ChangePasswordRequest.confirmedNew', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1527,
  serialized_end=1631,
)


_CHANGEPASSWORDRESPONSE = _descriptor.Descriptor(
  name='ChangePasswordResponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.ChangePasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1633,
  serialized_end=1657,
)


_RESETPASSWORDREQUEST = _descriptor.Descriptor(
  name='ResetPasswordRequest',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.ResetPasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.alert.v1.ResetPasswordRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.alert.v1.ResetPasswordRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new', full_name='github.com.metaprov.modelaapi.services.alert.v1.ResetPasswordRequest.new', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confirmedNew', full_name='github.com.metaprov.modelaapi.services.alert.v1.ResetPasswordRequest.confirmedNew', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1659,
  serialized_end=1749,
)


_RESETPASSWORDREPONSE = _descriptor.Descriptor(
  name='ResetPasswordReponse',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.ResetPasswordReponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1751,
  serialized_end=1773,
)

_LISTALERTSREQUEST_LABELSENTRY.containing_type = _LISTALERTSREQUEST
_LISTALERTSREQUEST.fields_by_name['labels'].message_type = _LISTALERTSREQUEST_LABELSENTRY
_LISTALERTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ALERTLIST
_CREATEALERTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ALERT
_UPDATEALERTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ALERT
_GETALERTRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ALERT
_GETALERTNAMESPACESRESPONSE.fields_by_name['namespaces'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._NAMESPACEINFO
DESCRIPTOR.message_types_by_name['ListAlertsRequest'] = _LISTALERTSREQUEST
DESCRIPTOR.message_types_by_name['ListAlertsResponse'] = _LISTALERTSRESPONSE
DESCRIPTOR.message_types_by_name['AlertResponse'] = _ALERTRESPONSE
DESCRIPTOR.message_types_by_name['CreateAlertRequest'] = _CREATEALERTREQUEST
DESCRIPTOR.message_types_by_name['CreateAlertResponse'] = _CREATEALERTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateAlertRequest'] = _UPDATEALERTREQUEST
DESCRIPTOR.message_types_by_name['UpdateAlertResponse'] = _UPDATEALERTRESPONSE
DESCRIPTOR.message_types_by_name['GetAlertRequest'] = _GETALERTREQUEST
DESCRIPTOR.message_types_by_name['GetAlertResponse'] = _GETALERTRESPONSE
DESCRIPTOR.message_types_by_name['GetAlertNamespacesRequest'] = _GETALERTNAMESPACESREQUEST
DESCRIPTOR.message_types_by_name['GetAlertNamespacesResponse'] = _GETALERTNAMESPACESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAlertRequest'] = _DELETEALERTREQUEST
DESCRIPTOR.message_types_by_name['DeleteAlertResponse'] = _DELETEALERTRESPONSE
DESCRIPTOR.message_types_by_name['AlertCreateResponse'] = _ALERTCREATERESPONSE
DESCRIPTOR.message_types_by_name['LogoutResponse'] = _LOGOUTRESPONSE
DESCRIPTOR.message_types_by_name['ResetPasswordResponse'] = _RESETPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['AlertLoginRequest'] = _ALERTLOGINREQUEST
DESCRIPTOR.message_types_by_name['AlertLoginResponse'] = _ALERTLOGINRESPONSE
DESCRIPTOR.message_types_by_name['AlertGetByNameRequest'] = _ALERTGETBYNAMEREQUEST
DESCRIPTOR.message_types_by_name['AlertLogoutRequest'] = _ALERTLOGOUTREQUEST
DESCRIPTOR.message_types_by_name['ChangePasswordRequest'] = _CHANGEPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['ChangePasswordResponse'] = _CHANGEPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['ResetPasswordRequest'] = _RESETPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['ResetPasswordReponse'] = _RESETPASSWORDREPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListAlertsRequest = _reflection.GeneratedProtocolMessageType('ListAlertsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTALERTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTALERTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest)
  })
_sym_db.RegisterMessage(ListAlertsRequest)
_sym_db.RegisterMessage(ListAlertsRequest.LabelsEntry)

ListAlertsResponse = _reflection.GeneratedProtocolMessageType('ListAlertsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ListAlertsResponse)
  })
_sym_db.RegisterMessage(ListAlertsResponse)

AlertResponse = _reflection.GeneratedProtocolMessageType('AlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.AlertResponse)
  })
_sym_db.RegisterMessage(AlertResponse)

CreateAlertRequest = _reflection.GeneratedProtocolMessageType('CreateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.CreateAlertRequest)
  })
_sym_db.RegisterMessage(CreateAlertRequest)

CreateAlertResponse = _reflection.GeneratedProtocolMessageType('CreateAlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.CreateAlertResponse)
  })
_sym_db.RegisterMessage(CreateAlertResponse)

UpdateAlertRequest = _reflection.GeneratedProtocolMessageType('UpdateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertRequest)
  })
_sym_db.RegisterMessage(UpdateAlertRequest)

UpdateAlertResponse = _reflection.GeneratedProtocolMessageType('UpdateAlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertResponse)
  })
_sym_db.RegisterMessage(UpdateAlertResponse)

GetAlertRequest = _reflection.GeneratedProtocolMessageType('GetAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.GetAlertRequest)
  })
_sym_db.RegisterMessage(GetAlertRequest)

GetAlertResponse = _reflection.GeneratedProtocolMessageType('GetAlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.GetAlertResponse)
  })
_sym_db.RegisterMessage(GetAlertResponse)

GetAlertNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetAlertNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.GetAlertNamespacesRequest)
  })
_sym_db.RegisterMessage(GetAlertNamespacesRequest)

GetAlertNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetAlertNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.GetAlertNamespacesResponse)
  })
_sym_db.RegisterMessage(GetAlertNamespacesResponse)

DeleteAlertRequest = _reflection.GeneratedProtocolMessageType('DeleteAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertRequest)
  })
_sym_db.RegisterMessage(DeleteAlertRequest)

DeleteAlertResponse = _reflection.GeneratedProtocolMessageType('DeleteAlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertResponse)
  })
_sym_db.RegisterMessage(DeleteAlertResponse)

AlertCreateResponse = _reflection.GeneratedProtocolMessageType('AlertCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALERTCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.AlertCreateResponse)
  })
_sym_db.RegisterMessage(AlertCreateResponse)

LogoutResponse = _reflection.GeneratedProtocolMessageType('LogoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.LogoutResponse)
  })
_sym_db.RegisterMessage(LogoutResponse)

ResetPasswordResponse = _reflection.GeneratedProtocolMessageType('ResetPasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ResetPasswordResponse)
  })
_sym_db.RegisterMessage(ResetPasswordResponse)

AlertLoginRequest = _reflection.GeneratedProtocolMessageType('AlertLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALERTLOGINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.AlertLoginRequest)
  })
_sym_db.RegisterMessage(AlertLoginRequest)

AlertLoginResponse = _reflection.GeneratedProtocolMessageType('AlertLoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALERTLOGINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.AlertLoginResponse)
  })
_sym_db.RegisterMessage(AlertLoginResponse)

AlertGetByNameRequest = _reflection.GeneratedProtocolMessageType('AlertGetByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALERTGETBYNAMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.AlertGetByNameRequest)
  })
_sym_db.RegisterMessage(AlertGetByNameRequest)

AlertLogoutRequest = _reflection.GeneratedProtocolMessageType('AlertLogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALERTLOGOUTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.AlertLogoutRequest)
  })
_sym_db.RegisterMessage(AlertLogoutRequest)

ChangePasswordRequest = _reflection.GeneratedProtocolMessageType('ChangePasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPASSWORDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ChangePasswordRequest)
  })
_sym_db.RegisterMessage(ChangePasswordRequest)

ChangePasswordResponse = _reflection.GeneratedProtocolMessageType('ChangePasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPASSWORDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ChangePasswordResponse)
  })
_sym_db.RegisterMessage(ChangePasswordResponse)

ResetPasswordRequest = _reflection.GeneratedProtocolMessageType('ResetPasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ResetPasswordRequest)
  })
_sym_db.RegisterMessage(ResetPasswordRequest)

ResetPasswordReponse = _reflection.GeneratedProtocolMessageType('ResetPasswordReponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ResetPasswordReponse)
  })
_sym_db.RegisterMessage(ResetPasswordReponse)


DESCRIPTOR._options = None
_LISTALERTSREQUEST_LABELSENTRY._options = None

_ALERTSERVICE = _descriptor.ServiceDescriptor(
  name='AlertService',
  full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1776,
  serialized_end=2759,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListAlerts',
    full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertService.ListAlerts',
    index=0,
    containing_service=None,
    input_type=_LISTALERTSREQUEST,
    output_type=_LISTALERTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\014\022\n/v1/alerts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateAlert',
    full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertService.CreateAlert',
    index=1,
    containing_service=None,
    input_type=_CREATEALERTREQUEST,
    output_type=_CREATEALERTRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\"\n/v1/alerts:\005alert',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAlert',
    full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertService.GetAlert',
    index=2,
    containing_service=None,
    input_type=_GETALERTREQUEST,
    output_type=_GETALERTRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\022\035/v1/{namespace}/alerts/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAlert',
    full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertService.UpdateAlert',
    index=3,
    containing_service=None,
    input_type=_UPDATEALERTREQUEST,
    output_type=_UPDATEALERTRESPONSE,
    serialized_options=b'\202\323\344\223\002E\032</v1/{alert.metadata.namespace}/alerts//{alert.metadata.name}:\005alert',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAlert',
    full_name='github.com.metaprov.modelaapi.services.alert.v1.AlertService.DeleteAlert',
    index=4,
    containing_service=None,
    input_type=_DELETEALERTREQUEST,
    output_type=_DELETEALERTRESPONSE,
    serialized_options=b'\202\323\344\223\002#*!/api/{namespace}/v1/alerts/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ALERTSERVICE)

DESCRIPTOR.services_by_name['AlertService'] = _ALERTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/connection/v1/connection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/connection/v1/connection.proto',
  package='github.com.metaprov.modelaapi.services.connection.v1',
  syntax='proto3',
  serialized_options=b'Z4github.com/metaprov/modelaapi/services/connection/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEgithub.com/metaprov/modelaapi/services/connection/v1/connection.proto\x12\x34github.com.metaprov.modelaapi.services.connection.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"\xc4\x01\n\x16ListConnectionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x02 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x17ListConnectionsResponse\x12T\n\x05items\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ConnectionList\"\x84\x02\n\x17\x43reateConnectionRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12i\n\x06secret\x18\x05 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1a\n\x18\x43reateConnectionResponse\"\x84\x02\n\x17UpdateConnectionRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12i\n\x06secret\x18\x02 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1a\n\x18UpdateConnectionResponse\"7\n\x14GetConnectionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x15GetConnectionResponse\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65leteConnectionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteConnectionResponse\"8\n\x15TestConnectionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"5\n\x16TestConnectionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xbc\n\n\x11\x43onnectionService\x12\xc7\x01\n\x0fListConnections\x12L.github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest\x1aM.github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/connections\x12\xd6\x01\n\x10\x43reateConnection\x12M.github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest\x1aN.github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x0f/v1/connections:\nconnection\x12\xc8\x01\n\rGetConnection\x12J.github.com.metaprov.modelaapi.services.connection.v1.GetConnectionRequest\x1aK.github.com.metaprov.modelaapi.services.connection.v1.GetConnectionResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/connections/{name}\x12\xf1\x01\n\x10UpdateConnection\x12M.github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest\x1aN.github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionResponse\">\x82\xd3\xe4\x93\x02\x38\x1a*/v1/connections/{connection.metadata.name}:\nconnection\x12\xe1\x01\n\x10\x44\x65leteConnection\x12M.github.com.metaprov.modelaapi.services.connection.v1.DeleteConnectionRequest\x1aN.github.com.metaprov.modelaapi.services.connection.v1.DeleteConnectionResponse\".\x82\xd3\xe4\x93\x02(*&/api/v1/connections/{namespace}/{name}\x12\xe0\x01\n\x0eTestConnection\x12K.github.com.metaprov.modelaapi.services.connection.v1.TestConnectionRequest\x1aL.github.com.metaprov.modelaapi.services.connection.v1.TestConnectionResponse\"3\x82\xd3\xe4\x93\x02-\x12+/api/v1/connections/{namespace}/{name}:testB6Z4github.com/metaprov/modelaapi/services/connection/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTCONNECTIONSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=425,
)

_LISTCONNECTIONSREQUEST = _descriptor.Descriptor(
  name='ListConnectionsRequest',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTCONNECTIONSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=425,
)


_LISTCONNECTIONSRESPONSE = _descriptor.Descriptor(
  name='ListConnectionsResponse',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=538,
)


_CREATECONNECTIONREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest.SecretEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=756,
  serialized_end=801,
)

_CREATECONNECTIONREQUEST = _descriptor.Descriptor(
  name='CreateConnectionRequest',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest.secret', index=1,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATECONNECTIONREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=541,
  serialized_end=801,
)


_CREATECONNECTIONRESPONSE = _descriptor.Descriptor(
  name='CreateConnectionResponse',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=803,
  serialized_end=829,
)


_UPDATECONNECTIONREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest.SecretEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=756,
  serialized_end=801,
)

_UPDATECONNECTIONREQUEST = _descriptor.Descriptor(
  name='UpdateConnectionRequest',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest.secret', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECONNECTIONREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=832,
  serialized_end=1092,
)


_UPDATECONNECTIONRESPONSE = _descriptor.Descriptor(
  name='UpdateConnectionResponse',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1094,
  serialized_end=1120,
)


_GETCONNECTIONREQUEST = _descriptor.Descriptor(
  name='GetConnectionRequest',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.GetConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.connection.v1.GetConnectionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.connection.v1.GetConnectionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1122,
  serialized_end=1177,
)


_GETCONNECTIONRESPONSE = _descriptor.Descriptor(
  name='GetConnectionResponse',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.GetConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.connection.v1.GetConnectionResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.connection.v1.GetConnectionResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1179,
  serialized_end=1297,
)


_DELETECONNECTIONREQUEST = _descriptor.Descriptor(
  name='DeleteConnectionRequest',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.DeleteConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.connection.v1.DeleteConnectionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.connection.v1.DeleteConnectionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1299,
  serialized_end=1357,
)


_DELETECONNECTIONRESPONSE = _descriptor.Descriptor(
  name='DeleteConnectionResponse',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.DeleteConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1359,
  serialized_end=1385,
)


_TESTCONNECTIONREQUEST = _descriptor.Descriptor(
  name='TestConnectionRequest',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.TestConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.connection.v1.TestConnectionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.connection.v1.TestConnectionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1387,
  serialized_end=1443,
)


_TESTCONNECTIONRESPONSE = _descriptor.Descriptor(
  name='TestConnectionResponse',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.TestConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='github.com.metaprov.modelaapi.services.connection.v1.TestConnectionResponse.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='github.com.metaprov.modelaapi.services.connection.v1.TestConnectionResponse.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1445,
  serialized_end=1498,
)

_LISTCONNECTIONSREQUEST_LABELSENTRY.containing_type = _LISTCONNECTIONSREQUEST
_LISTCONNECTIONSREQUEST.fields_by_name['labels'].message_type = _LISTCONNECTIONSREQUEST_LABELSENTRY
_LISTCONNECTIONSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTIONLIST
_CREATECONNECTIONREQUEST_SECRETENTRY.containing_type = _CREATECONNECTIONREQUEST
_CREATECONNECTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_CREATECONNECTIONREQUEST.fields_by_name['secret'].message_type = _CREATECONNECTIONREQUEST_SECRETENTRY
_UPDATECONNECTIONREQUEST_SECRETENTRY.containing_type = _UPDATECONNECTIONREQUEST
_UPDATECONNECTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_UPDATECONNECTIONREQUEST.fields_by_name['secret'].message_type = _UPDATECONNECTIONREQUEST_SECRETENTRY
_GETCONNECTIONRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
DESCRIPTOR.message_types_by_name['ListConnectionsRequest'] = _LISTCONNECTIONSREQUEST
DESCRIPTOR.message_types_by_name['ListConnectionsResponse'] = _LISTCONNECTIONSRESPONSE
DESCRIPTOR.message_types_by_name['CreateConnectionRequest'] = _CREATECONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['CreateConnectionResponse'] = _CREATECONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['UpdateConnectionRequest'] = _UPDATECONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateConnectionResponse'] = _UPDATECONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['GetConnectionRequest'] = _GETCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['GetConnectionResponse'] = _GETCONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteConnectionRequest'] = _DELETECONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteConnectionResponse'] = _DELETECONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['TestConnectionRequest'] = _TESTCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['TestConnectionResponse'] = _TESTCONNECTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListConnectionsRequest = _reflection.GeneratedProtocolMessageType('ListConnectionsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCONNECTIONSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCONNECTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest)
  })
_sym_db.RegisterMessage(ListConnectionsRequest)
_sym_db.RegisterMessage(ListConnectionsRequest.LabelsEntry)

ListConnectionsResponse = _reflection.GeneratedProtocolMessageType('ListConnectionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONNECTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsResponse)
  })
_sym_db.RegisterMessage(ListConnectionsResponse)

CreateConnectionRequest = _reflection.GeneratedProtocolMessageType('CreateConnectionRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATECONNECTIONREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest)
  })
_sym_db.RegisterMessage(CreateConnectionRequest)
_sym_db.RegisterMessage(CreateConnectionRequest.SecretEntry)

CreateConnectionResponse = _reflection.GeneratedProtocolMessageType('CreateConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionResponse)
  })
_sym_db.RegisterMessage(CreateConnectionResponse)

UpdateConnectionRequest = _reflection.GeneratedProtocolMessageType('UpdateConnectionRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECONNECTIONREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest)
  })
_sym_db.RegisterMessage(UpdateConnectionRequest)
_sym_db.RegisterMessage(UpdateConnectionRequest.SecretEntry)

UpdateConnectionResponse = _reflection.GeneratedProtocolMessageType('UpdateConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionResponse)
  })
_sym_db.RegisterMessage(UpdateConnectionResponse)

GetConnectionRequest = _reflection.GeneratedProtocolMessageType('GetConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.GetConnectionRequest)
  })
_sym_db.RegisterMessage(GetConnectionRequest)

GetConnectionResponse = _reflection.GeneratedProtocolMessageType('GetConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.GetConnectionResponse)
  })
_sym_db.RegisterMessage(GetConnectionResponse)

DeleteConnectionRequest = _reflection.GeneratedProtocolMessageType('DeleteConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.DeleteConnectionRequest)
  })
_sym_db.RegisterMessage(DeleteConnectionRequest)

DeleteConnectionResponse = _reflection.GeneratedProtocolMessageType('DeleteConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.DeleteConnectionResponse)
  })
_sym_db.RegisterMessage(DeleteConnectionResponse)

TestConnectionRequest = _reflection.GeneratedProtocolMessageType('TestConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _TESTCONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.TestConnectionRequest)
  })
_sym_db.RegisterMessage(TestConnectionRequest)

TestConnectionResponse = _reflection.GeneratedProtocolMessageType('TestConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTCONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.TestConnectionResponse)
  })
_sym_db.RegisterMessage(TestConnectionResponse)


DESCRIPTOR._options = None
_LISTCONNECTIONSREQUEST_LABELSENTRY._options = None
_CREATECONNECTIONREQUEST_SECRETENTRY._options = None
_UPDATECONNECTIONREQUEST_SECRETENTRY._options = None

_CONNECTIONSERVICE = _descriptor.ServiceDescriptor(
  name='ConnectionService',
  full_name='github.com.metaprov.modelaapi.services.connection.v1.ConnectionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1501,
  serialized_end=2841,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListConnections',
    full_name='github.com.metaprov.modelaapi.services.connection.v1.ConnectionService.ListConnections',
    index=0,
    containing_service=None,
    input_type=_LISTCONNECTIONSREQUEST,
    output_type=_LISTCONNECTIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/connections',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateConnection',
    full_name='github.com.metaprov.modelaapi.services.connection.v1.ConnectionService.CreateConnection',
    index=1,
    containing_service=None,
    input_type=_CREATECONNECTIONREQUEST,
    output_type=_CREATECONNECTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\017/v1/connections:\nconnection',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetConnection',
    full_name='github.com.metaprov.modelaapi.services.connection.v1.ConnectionService.GetConnection',
    index=2,
    containing_service=None,
    input_type=_GETCONNECTIONREQUEST,
    output_type=_GETCONNECTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/connections/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateConnection',
    full_name='github.com.metaprov.modelaapi.services.connection.v1.ConnectionService.UpdateConnection',
    index=3,
    containing_service=None,
    input_type=_UPDATECONNECTIONREQUEST,
    output_type=_UPDATECONNECTIONRESPONSE,
    serialized_options=b'\202\323\344\223\0028\032*/v1/connections/{connection.metadata.name}:\nconnection',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteConnection',
    full_name='github.com.metaprov.modelaapi.services.connection.v1.ConnectionService.DeleteConnection',
    index=4,
    containing_service=None,
    input_type=_DELETECONNECTIONREQUEST,
    output_type=_DELETECONNECTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002(*&/api/v1/connections/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TestConnection',
    full_name='github.com.metaprov.modelaapi.services.connection.v1.ConnectionService.TestConnection',
    index=5,
    containing_service=None,
    input_type=_TESTCONNECTIONREQUEST,
    output_type=_TESTCONNECTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002-\022+/api/v1/connections/{namespace}/{name}:test',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONNECTIONSERVICE)

DESCRIPTOR.services_by_name['ConnectionService'] = _CONNECTIONSERVICE

# @@protoc_insertion_point(module_scope)
